@@ -59,7 +59,6 @@ class Client:
         self.followers_count = 0
         self.following_count = 0
 
-
         self.file_name_time_pattern = datetime.now().strftime("%Y-%m-%d %H")
        
 
@@ -145,15 +144,17 @@ class Client:
             self.follows_max = int(self.follows_max[0].strip())
 
         #unfollows max
-        self.unfollows_max = config_api.get("unfollows", config.get("unfollows", 0))
+        self.unfollows_max = config_api.get("unfollows", config.get("unfollows", 0)).split("-")
         if len(self.unfollows_max) == 2:
             self.unfollows_max = randint(int(self.unfollows_max[0].strip()),int(self.unfollows_max[1].strip()))
         else:
             self.unfollows_max = int(self.unfollows_max[0].strip())
         
         self.wait_between = int(config_api.get("between_runs", config.get("between_runs" , 2)))
+     
         self.run_between = config_api.get("run_between", config.get("run_between" , 0))
-        
+        self.status = int(config_api.get("status", 1))
+
 
         
     def get_popup(self):
@@ -214,6 +215,11 @@ class Client:
         d2 = datetime.strptime(d2, "%Y-%m-%d %H:%M:%S")
         return round(abs((d2 - d1).total_seconds()/3600),1)
     def is_runable(self):
+        #status is 0 do not run
+        if self.status == 0:
+            return False
+
+
         userblock_exists = os.path.isfile(self.path  + "block.user")
         log_exists = os.path.isfile(self.path  + self.user + ".log")
         lastRun = False
